@@ -11,10 +11,22 @@ from versionlib.dotnet import SourcePackageVersion, RuntimeIdentifier
 def GetSourceBuiltArtifactsTarball(
         basePath: str, 
         sdkVersion: str, 
-        runtimeIdentifier: str) -> str:
-    globPattern =  (f"{basePath}/Private.SourceBuilt.Artifacts."
-                    f"{sdkVersion}*.tar.gz")
+        runtimeIdentifier: str,
+        type: str = "Packages") -> str:
+    
+    globPattern = ""
 
+    if type == "Packages":
+        # e.g. Private.SourceBuilt.Artifacts.9.0.100-preview.7.24407.1.ubuntu.24.10-x64.tar.gz
+        globPattern =  (f"{basePath}/Private.SourceBuilt.Artifacts."
+                        f"{sdkVersion}*.{runtimeIdentifier}.tar.gz")
+    elif type == "SDK":
+        # e.g. dotnet-sdk-9.0.100-preview.7.24407.1-ubuntu.24.10-x64.tar.gz
+        globPattern =  (f"{basePath}/dotnet-sdk-"
+                        f"{sdkVersion}*-{runtimeIdentifier}.tar.gz")
+    else:
+        raise ValueError(f"Unknown source built artifacts tarball type '{type}'.")
+    
     files = glob(globPattern)
 
     if len(files) == 0:
